

/**
 * Je suis un producteur qui produit des instances de la classe Product. Je range ma production dans une instance de la classe Stock.
 * 
 * @author F.Dagnat
 * @version 2
 */

public class Producer {

	/**
	 * Chaque producteur recoit un nom. Ce nom peut etre modifie par setName et accede par getName
	 */
	private String name;

	/**
	 * Chaque producteur est lie a un Stock qui lui est attribue a sa creation
	 */
	private final Stock myStock;

	/**
	 * Construit un producteur en lui attribuant un nom et un Stock.
	 * 
	 * @param name le nom du producteur
	 * @param Stock le Stock qui lui est attribue
	 * @throws NullPointerException si un des parametres n'est pas initialise
	 */
	public Producer(String name, Stock stock) {
		if (name == null || stock == null)
			throw new NullPointerException();
		this.myStock = stock;
		this.name = name;
	}

	/**
	 * Rend le nom du producteur
	 */
	public String getName() {
		return this.name;
	}

	/**
	 * Rend le Stock associe au producteur
	 */
	public Stock getStock() {
		return this.myStock;
	}

	/**
	 * Un Producteur produit en mettant un nouveau produit dont le nom est passe en argument dans le Stock.
	 * 
	 * @param productName le nom du produit a produire
	 */
	public void produce(String productName) {
		if (productName != null)
			this.myStock.add(new Product(productName));
	}

	/**
	 * Modifie le nom du producteur
	 * 
	 * @param name le nouveau nom du producteur
	 */
	public void setName(String name) {
		if (name != null)
			this.name = name;
	}

	/**
	 * Rend une chaine qui decrit les caracteristiques du producteur.
	 */
	@Override
	public String toString() {
		return "Producteur " + this.name;
	}
}
