

/**
 * Classe representant un produit. Un produit possede un nom et un numero qui correspond a son rang de creation. Il est possible de
 * recuperer ce nom, ce numero et de transformer un produit en chaine de caracteres. Il est egalement possible de savoir le nombre de
 * produits deja crees.
 * 
 * @author F.Dagnat
 * @version 2
 */
public class Product {
	/**
	 * Nom du produit.
	 */
	private final String name;

	/**
	 * Nombre de produits deja crees. Permet d'attribuer un numero a chaque produit, ce numero est incremente a chaque instanciation
	 */
	private static int numberCreated = 0;

	/** Le numero du produit */
	private final int number;

	/**
	 * Constructeur qui prend en parametre le nom du nouveau produit
	 * 
	 * @param nom du produit a creer
	 * @throws NullPointerException si name est null
	 */
	public Product(String name) {
		if (name == null)
			throw new NullPointerException();
		this.name = name;
		this.number = ++numberCreated;
	}

	/**
	 * Rend une chaine de caracteres qui est le nom du produit
	 * 
	 * @return le nom du produit
	 */
	public String getName() {
		return this.name;
	}

	/**
	 * Rend le numero du produit
	 * 
	 * @return numero du produit
	 */
	public int getNumber() {
		return this.number;
	}

	/**
	 * Rend une chaine de caracteres qui decrit le produit
	 */
	@Override
	public String toString() {
		return "Produit " + this.name + " de num " + this.number;
	}

	/**
	 * Rend le nombre de produits crees
	 * 
	 * @return nombre de produits crees
	 */
	public static int getNumberCreated() {
		return numberCreated;
	}
}
